Eps: Inverse cumulative distribution function for a subset of the...

View source: R/Eps.R

EpsR Documentation

Inverse cumulative distribution function for a subset of the dataset

Description

Inverse cumulative distribution function for a subset of the dataset

Usage

Eps(p, data, group = "qtyvar")

Arguments

p

cumulative distribution percentile

data

dataset with defined group and newwts columns

group

variable of interest

Value

Cumulative distribution percentile for quantile y

Examples


df_samp <- data.frame(qtyvar = rnorm(1000, mean = 5, sd = 2),newwts = rep(1, 1000))
Eps(0.25,df_samp)
# Finds the quantile for 25th percentile in simulated data.

glorenz documentation built on June 8, 2025, 10:46 a.m.

Related to Eps in glorenz...