Fd: Cumulative distribution function for a subset of the dataset

View source: R/Fd.R

FdR Documentation

Cumulative distribution function for a subset of the dataset

Description

Cumulative distribution function for a subset of the dataset

Usage

Fd(y, data, group = "qtyvar", newwts = "newwts")

Arguments

y

cumulative distribution quantile

data

dataset with defined group and newwts columns

group

variable of interest

newwts

sampling weights

Value

Cumulative distribution percentile for quantile y

Examples


df_samp <- data.frame(qtyvar = rnorm(1000, mean = 5, sd = 2),newwts = rep(1, 1000))
Fd(3.5,df_samp)
# Finds the percentile for 3.5 in simulated data.

glorenz documentation built on June 8, 2025, 10:46 a.m.

Related to Fd in glorenz...