Learn R Programming

glorenz (version 0.1.1)

Eps: Inverse cumulative distribution function for a subset of the dataset

Description

Inverse cumulative distribution function for a subset of the dataset

Usage

Eps(p, data, group = "qtyvar")

Value

Cumulative distribution percentile for quantile y

Arguments

p

cumulative distribution percentile

data

dataset with defined group and newwts columns

group

variable of interest

Examples

Run this code

df_samp <- data.frame(qtyvar = rnorm(1000, mean = 5, sd = 2),newwts = rep(1, 1000))
Eps(0.25,df_samp)
# Finds the quantile for 25th percentile in simulated data.

Run the code above in your browser using DataLab