Learn R Programming

glorenz (version 0.1.1)

Fd: Cumulative distribution function for a subset of the dataset

Description

Cumulative distribution function for a subset of the dataset

Usage

Fd(y, data, group = "qtyvar", newwts = "newwts")

Value

Cumulative distribution percentile for quantile y

Arguments

y

cumulative distribution quantile

data

dataset with defined group and newwts columns

group

variable of interest

newwts

sampling weights

Examples

Run this code

df_samp <- data.frame(qtyvar = rnorm(1000, mean = 5, sd = 2),newwts = rep(1, 1000))
Fd(3.5,df_samp)
# Finds the percentile for 3.5 in simulated data.

Run the code above in your browser using DataLab